import {AdRecord} from '../records/ad.record';
import {pool} from '../utils/db';
import {AdEntity} from '../types';

const defaultObj = {
    name: 'Test Name',
    description: 'Test Description',
    url: 'http://megak.pl',
    price: 0,
    lat: 9,
    lon: 9
};

afterAll(async () => {
    await pool.end();
});

test('AdRecord returns data from database for one entry', async () => {

    const ad = await AdRecord.getOne('abc');
    console.log(ad);

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('TestowyDB');
});

test('AdRecord.getOne returns null from database for unexisting entry', async () => {

    const ad = await AdRecord.getOne('Nieistniejące ID');
    console.log(ad);

    expect(ad).toBeNull();
});

test('AdRecord.getAll returns array from of found entries', async () => {

    const ads = await AdRecord.findAll('');
    console.log(ads);

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.getAll returns array from of found entries when searching for "e" ', async () => {

    const ads = await AdRecord.findAll('e');
    console.log(ads);

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.getAll returns empty array when for something that does not exist ', async () => {

    const ads = await AdRecord.findAll('-------------');

    expect(ads).toEqual([]);
});

test('AdRecord.getAll returns smaller amount of data', async () => {

    const ads = await AdRecord.findAll('');

    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
});

test('AdRecord.insert returns new UUID', async () => {

    const ad = new AdRecord(defaultObj);
    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
});

test('AdRecord.insert inserts data to database', async () => {

    const ad = new AdRecord(defaultObj);
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id)

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
});